#
# spec file for package python-hyperlink
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-hyperlink
Version:        21.0.0
Release:        2.3
Summary:        Immutable URL support for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/python-hyper/hyperlink
Source:         https://files.pythonhosted.org/packages/source/h/hyperlink/hyperlink-%{version}.tar.gz
BuildRequires:  %{python_module idna >= 2.5}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-idna >= 2.5
BuildArch:      noarch
%python_subpackages

%description
Hyperlink provides a pure-Python implementation of immutable URLs
based on RFC 3986 and 3987.

%prep
%setup -q -n hyperlink-%{version}

%build

%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md docs/*.rst
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Mar 13 2021 Dirk Müller <dmueller@suse.com>
- update to 21.0.0:
  * Update plus sign (+) handling to work with/like HTML form encoding (POST)
    by default, fixes #129, and associated roundtripping (#146).
  * Package IDNA tables.
  * Long overdue dependency bumps
* Mon Sep 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.0.1:
  * CPython 3.7 and 3.8 and PyPy3 added to test matrix
  * Hyperlink now has type hints and they are now exported per
  [PEP 561](https://www.python.org/dev/peps/pep-0561/).
  * Several bugs related to hidden state were fixed, making it so that all data
  on a `URL` object (including `rooted` and `uses_netloc`) is reflected by and
  consistent with its textual representation.
  This does mean that sometimes these constructor arguments are ignored, if it
  would create invalid or unparseable URL text.
* Wed May 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add missing runtime dependency on idna
* Tue May 21 2019 pgajdos@suse.com
- version update to 19.0.0
  * When passed to `str()` URLs now stringify to usable URL
    strings. (See #49)
  * Switched off of Python's built-in IDNA facilities to using the
    [idna](https://pypi.python.org/pypi/idna) package. Not only is it
    much more modern, it's also much more strict and correct in its
    output. (See #19 and #56)
  * Added new `DecodedURL` type with almost-identical API to the normal
    `URL`, except that it automatically handles reserved characters in
    argument values passed to its methods. (See #6, #11, #44)
  * Added top-level `parse()` convenience function that now represents
    the main entrypoint to hyperlink.
  * Accept dictionaries as ‘query=’ arguments, in addition to
    sequences of tuples (see #50)
  * `URL.child()` will no longer fail when child gets no segments (#42 and #43)
  * `URL.normalize()` now supports encoding stray/unmatched `%%` characters
    in character-encoded fields (userinfo, path, query string, fragment)
    (see #61, #62)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Jul  4 2017 jengelh@inai.de
- Replace description.
* Tue Jul  4 2017 tbechtold@suse.com
- initial packaging (version 17.2.1)
